summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorvboxsync <vboxsync@cfe28804-0f27-0410-a406-dd0f0b0b656f>2023-05-10 13:20:23 +0000
committervboxsync <vboxsync@cfe28804-0f27-0410-a406-dd0f0b0b656f>2023-05-10 13:20:23 +0000
commitfe022938533c1ead723210bb1bc97a26eb926185 (patch)
tree0c220855f3ace42f0b7f05bde566ffea6f5fe8ea
parent276eb52f3c4d11765b4d9441893814600f2a7cb2 (diff)
downloadVirtualBox-svn-fe022938533c1ead723210bb1bc97a26eb926185.tar.gz
Audio/Settings: Also use the PulseAudio backend when we find pipewire-pulse running (instead of falling back to ALSA), which acts as a PulseAudio-compatible daemon for Pipewire-enabled applications. Thanks to Aroun! ticketref:21575
git-svn-id: https://www.virtualbox.org/svn/vbox/trunk@99723 cfe28804-0f27-0410-a406-dd0f0b0b656f
-rw-r--r--src/VBox/Main/xml/Settings.cpp7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/VBox/Main/xml/Settings.cpp b/src/VBox/Main/xml/Settings.cpp
index a6a06cad7af..b6267679e65 100644
--- a/src/VBox/Main/xml/Settings.cpp
+++ b/src/VBox/Main/xml/Settings.cpp
@@ -8939,8 +8939,11 @@ AudioDriverType_T MachineConfigFile::getHostDefaultAudioDriver()
if (s_enmLinuxDriver == AudioDriverType_Null) /* Already determined from a former run? */
{
# ifdef VBOX_WITH_AUDIO_PULSE
- /* Check for the pulse library & that the pulse audio daemon is running. */
- if ( RTProcIsRunningByName("pulseaudio")
+ /* Check for the pulse library & that the PulseAudio daemon is running. */
+ if ( ( RTProcIsRunningByName("pulseaudio")
+ /* We also use the PulseAudio backend when we find pipewire-pulse running, which
+ * acts as a PulseAudio-compatible daemon for Pipewire-enabled applications. See @ticketref{21575} */
+ || RTProcIsRunningByName("pipewire-pulse"))
&& RTLdrIsLoadable("libpulse.so.0"))
{
s_enmLinuxDriver = AudioDriverType_Pulse;